# BreezyHR Connector

## About BreezyHR :

BreezyHr is a software designed to assist teams in finding the right candidates, evaluating applicants, and making a hire more quickly.
It helps streamline the recruitment process and identify the best fit for a position.

## Connector features :

- **Push profiles :**  Retrieves profiles from HrFlow Souce export API and sends them to BreezyHR ATS
- **Pull Jobs :** Retrieves jobs from BreezyHR vacancies export API  and sends them to a [HrFlow.ai](http://HrFlow.ai) Board

**Useful links:**

📄Visit [BreezyHR](https://breezy.hr/) to learn more.

💻 [Connector code](https://github.com/Riminder/hrflow-connectors/tree/master/src/hrflow_connectors/connectors/breezyhr) on our Github.

**Screenshots :**

- **Push profiles :**
![image](https://user-images.githubusercontent.com/55802491/212358414-f29104b6-c54b-4f91-b376-1fe7b5fb8eb1.png)

    
- **Pull Jobs :**
![image](https://user-images.githubusercontent.com/55802491/210258882-e9e0abda-62a5-4267-89f0-61460c10abe1.png)
